Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(658)

Unified Diff: Source/core/dom/EventTarget.h

Issue 106423003: [oilpan] Rename visit to mark. (Closed) Base URL: svn://svn.chromium.org/blink/branches/oilpan
Patch Set: Fix typo Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/dom/EventTarget.h
diff --git a/Source/core/dom/EventTarget.h b/Source/core/dom/EventTarget.h
index 60a9e45a0b4991db8efeda1b441479dd5dd4204e..a5d49941aa74d1bd18c2ab2e5137df4492fa9eeb 100644
--- a/Source/core/dom/EventTarget.h
+++ b/Source/core/dom/EventTarget.h
@@ -127,12 +127,12 @@ namespace WebCore {
bool fireEventListeners(Event*);
bool isFiringEventListeners();
// We can't pass an EventTarget pointer into Visitor::visit directly
// because it does not coincide with the actual start of the object and
// the visitor has to access the object header. Thus we need a helper
// method that correctly adjusts the pointer before passing it into the
// visitor.
- virtual void visitWith(Visitor*) const = 0;
+ virtual void adjustAndMark(Visitor*) const = 0;
protected:
virtual ~EventTarget();
@@ -198,7 +198,7 @@ namespace WebCore {
template<> class TraceTrait<EventTarget> {
public:
- static void visit(Visitor* visitor, const EventTarget* self) { self->visitWith(visitor); }
+ static void mark(Visitor* visitor, const EventTarget* self) { self->adjustAndMark(visitor); }
static intptr_t getTypeMarker() { return 0; }

Powered by Google App Engine
@@ -127,12 +127,12 @@ namespace WebCore {
bool fireEventListeners(Event*);
bool isFiringEventListeners();
- // We can't pass an EventTarget pointer into Visitor::visit directly
+ // We can't pass an EventTarget pointer into Visitor::mark directly
// because it does not coincide with the actual start of the object and
// the visitor has to access the object header. Thus we need a helper
This is Rietveld 408576698